<?php

/**
 * @file
 * Post update functions for ECA.
 */

/**
 * Rename used tokens in available ECA models for ECA 2.0.0.
 */
function eca_post_update_rename_tokens_2_0_0(): void {
  $tokenNames = [
    'event:content-type',
    'event:entity-bundle',
    'event:entity-id',
    'event:entity-type',
    'event:extra-field-name',
    'event:field-name',
    'event:machine-name',
    'event:parent-bundle',
    'event:parent-id',
    'event:parent-type',
    'event:path-arguments',
    'event:route-parameters',
    'event:view-display',
    'event:view-id',
    'form:base-id',
    'form:num-errors',
  ];
  $storage = \Drupal::entityTypeManager()->getStorage('eca');
  /** @var \Drupal\eca\Entity\Eca $eca */
  foreach ($storage->loadMultiple() as $eca) {
    $changed = FALSE;
    $modelData = $eca->getModel()->getModeldata();
    foreach (['conditions', 'actions'] as $type) {
      $items = $eca->get($type) ?? [];
      foreach ($items as &$item) {
        if (!empty($item['configuration'])) {
          foreach ($item['configuration'] as $key => $value) {
            foreach ($tokenNames as $tokenName) {
              $oldToken = '[' . $tokenName . ']';
              $newToken = '[' . str_replace('-', '_', $tokenName) . ']';
              if (str_contains($value, $oldToken)) {
                $item['configuration'][$key] = str_replace($oldToken, $newToken, $value);
                $modelData = str_replace($oldToken, $newToken, $modelData);
                $changed = TRUE;
              }
            }
          }
        }
      }
      unset($item);
      $eca->set($type, $items);
    }
    if ($changed) {
      if ($modelData !== '') {
        $eca->getModel()->setModeldata($modelData)->save();
      }
      $eca->save();
    }
  }
}
